#!/usr/bin/perl
#
#  Script for displaying an overview of documents available in the help system.
#
#  This file is part of the SuSE help system.
#
#  Copyright (C) 2002  SuSE Linux AG, Nuernberg
#
#  Author: Cornelius Schumacher <cschum@suse.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#use strict;

use utf8;

use FindBin;
use lib $FindBin::Bin;

use File::Basename;

use susehelp;

&checkQuery;
&parseQuery;

$lang = lc getQuery( "lang", "en" );
$metapath = getQuery( "path", "" );
$depth = getQuery( "depth", 0 );
$cgiprefix = getQuery( "cgiprefix", "cgi:" );
$header = getQuery( "header", 0 );
$showall = getQuery( "showall", 0 );
$fileprefix = getQuery( "fileprefix", "file:" );

&setLanguage( $lang );

&registerCgiPrefix( $cgiprefix );

# for the web server
&printCgiHeader;

my $out;

if ( $header ) {
  $out = "--HEADER_FULL:--";
} else {
  $out = "--HEADER:--";
}

$dirpath = "$susehelp::metadir/$metapath";
$entry = basename $metapath;

#$out .= "DIRPATH: $dirpath<br>ENTRY: $entry<br>\n";

if ( $metapath ) {
  my $docentry = readDesktopFile( "$dirpath/.directory", $entry, $lang );
  if ( !$docentry ) {
    $title = $entry;
  } else {
    $title = $docentry->name();
    $comment = $docentry->comment();
  }

  $out .= "<h1>$title</h1>\n";
  
  if ( $comment ) {
    $out .= "<p>$comment</p>\n";
  }
}

&traverseMetaDir( $metapath, $depth, $lang, "::showfileentry", "::showdirentry",
                  "::dirdown", "::dirup", $showall );

if ( $header ) {
  $out .= "--FOOTER_FULL:--";
} else {
  $out .= "--FOOTER:--";
}

&printPage( $out );

exit 0;

sub showfileentry($)
{
  my $docentry = shift;
  
  my ( $name, $comment, $docpath );

#  print STDERR "  showfileentry()\n";

  $name = $docentry->name;
  $comment = $docentry->comment;

#  print STDERR "SHOWFILEENTRY: $name\n";

  my $docpath = $docentry->docpath();

#  print STDERR "  docpath: $docpath\n"; 
    
  if ( !$docpath ) {
    my $path = $docentry->path();
    $docpath = createCgiUrl( "showdir.cgi" ) . "&path=$path";
  } else {
    $docpath = processDocPath( $docpath );
  }

#  if ( $name !~ /^en/ ) {
#    print STDERR "Ignore: $name\n";
#    return;
#  } else {
#    print STDERR "Take: $name\n";
#  }

  if ( $docpath ) {
    $out .= "<li><a href=\"$docpath\">$name</a><br>$comment</li>\n";
  } else {
    if ( $showall ) {
      $out .= "<li><em>$name</em></li>\n";
    }
  }
}

sub showdirentry($$)
{
  my $docentry = shift;
  my $path = shift;

#  print STDERR "SHOWDIRENTRY: PATH: $path\n";

  my ( $name, $comment, $docpath );

  $name = $docentry->name;
  $comment = $docentry->comment;
  $docpath = $docentry->docpath;

  if ( !$docpath ) {
    $docpath = createCgiUrl( "showdir.cgi" ) . "&path=$path";
  } else {
    $docpath = processDocPath( $docpath );
  }
  
  $out .= "<li><b>";
  $out .= "<a href=\"$docpath\">$name</a></b>\n";
  if ( $comment ) { $out .= "<br>$comment\n"; }
  $out .= "</li>\n";
}

sub dirdown()
{
  $out .= "<ul>\n";
}

sub dirup()
{
  $out .= "</ul>\n";
}

sub processDocPath($)
{
  my $docPath = shift;

  if ( !$docPath ) { return; }
  if ( $docPath =~ /^(.*):(.*)/ ) {
    my $prefix = $1;
    my $urlpath = $2;
    if ( $prefix eq "cgi" ) {
      $docPath = createCgiUrl( $urlpath, $lang );
    } else {
      if ( $fileprefix eq "file:" ) {
        # we are in local no-docserver mode
        if ( $prefix eq "man" || $prefix eq "info" || $prefix eq "help" ||
             $prefix eq "ghelp" ) {
          return $docPath;
        }
      }
      if ( $prefix ne "http" ) { return; }
    }
  } else {
    if ( !-e $docPath ) { return; }
  }

  if ( $docPath =~ /^\// ) {
    $docPath = $fileprefix . $docPath;
  }
  
  return $docPath;
}
