#!/usr/bin/perl
#
#  Wrapper script for creating search indices for htdig.
#
#  This file is part of the SuSE help system.
#
#  Copyright (C) 2002  SuSE Linux AG, Nuernberg
#
#  Author: Cornelius Schumacher <cschum@suse.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

do "/usr/share/susehelp/susehelprc";

push @INC, $susehelpcgidir;

use Getopt::Long;

require susehelp;
import susehelp;

GetOptions (
  'indexdir=s' => \$indexdir,
  'help' => \$help,
);

$| = 1; # autoflush buffers

if ( @ARGV != 1 || $help ) {
  print "Usage: genhtdig --indexdir <indexdir> <desktopfile>\n";
  exit 1;
}

$metafile = $ARGV[0];

if ( !$indexdir ) { $indexdir = $susehelp::default_indexdir; }

if ( $metafile !~ /^\// ) { $metafile = "$metadir/" . $metafile; }

&dbg( "METAFILE: $metafile" );
&dbg( "INDEXDIR: $indexdir" );

if ( !open( META, $metafile ) ) {
  print STDERR "Unable to open file '$metafile'.\n";
  exit 1;
}

&dbg( "---START---" );
while ( <META> ) {
  if ( /^DocPath=(.*)$/ ) {
    $docpath = $1;
    &dbg( "DOCPATH: $1" );
  }
  if ( /^X-DOC-Identifier=(.*)$/ ) {
    $identifier = $1;
  }
  chop;
  &dbg( $_ );
}
&dbg( "---END---" );

close META;

if ( $metafile =~ /.directory$/ ) {
  $identifier =~ /(..)$/;
  $lang = $1;
} elsif ( $metafile =~ /.*\/([^\/]*)\.desktop$/ ) {
  $metaname = $1;

  $metaname =~ /.+\.(..)$/;
  $lang = $1;
}

if ( $identifier ) { $metaname = $identifier; }

$cleanmetaname = $metaname;
$cleanmetaname =~ s/\.//g;
$cleanmetaname =~ s/\-//g;

&dbg( "METANAME: $metaname" );

# Find help file for KDE docs
if ( $docpath =~ /^help:\/?([^\/]*)/ ) {
  my $app = $1;
  &dbg( "APP: $app" );
  $docpath = "/opt/kde3/share/doc/HTML/en/$app/index.docbook";
}

print "Creating index for <b>'$metaname'</b>\n";

$htdigconf = $indexdir;
$htdigdb = $indexdir;

$conffile = "$htdigconf/$cleanmetaname.conf";

if ( !open( CONF, ">$conffile" ) ) {
  print STDERR "Unable to open '$conffile' for writing.\n";
  exit 1;
}

$commondir = "$htdigsusehelp/$lang";

if ( !$lang || !-e $commondir ) {
  $commondir = "$htdigsusehelp/en";
}

if ( $lang eq "de" ) { $locale = "de_DE"; }
else { $locale = $lang; }

print CONF << "EOT";
# htdig configuration for doc '$metaname'
#
# This file has been automatically created by the SuSE help system.

common_dir:		$commondir
locale:                 $locale
database_dir:           $htdigdb
local_urls:		http://localhost=
local_urls_only:	true
limit_urls_to:          http://localhost
ignore_noindex:		true
max_hop_count:		4
robotstxt_name:         susedig
compression_level:	6
template_map:           Long long $htdigsusehelp/long.html \\
                        Short short $htdigsusehelp/short.html
search_algorithm:       exact:1 prefix:0.8
maximum_pages:          1
matches_per_page:       10
database_base:		\${database_dir}/$metaname
start_url:		http://localhost/$docpath
# for pdf-files
max_doc_size:           5000000
external_parsers: application/pdf /usr/share/doc/packages/htdig/contrib/parse_doc.pl      application/postscript /usr/share/doc/packages/htdig/contrib/parse_doc.pl
#external_parsers: text/docbook /build/htdig/parser
EOT

close CONF;

$ENV{ PATH } = '';

$ret = system( "$htdigbin/htdig -s -i -c $conffile" );
if ( $ret != 0 ) {
  print STDERR "htdig failed\n";
} else {
  $ret = system( "$htdigbin/htmerge -c $conffile" );
  if ( $ret != 0 ) { print STDERR "htmerge failed\n"; }
}

if ( $ret == 0 ) {
  my $existsfile = "$indexdir/$metaname.exists";

  if ( !open( EXISTS, ">$existsfile" ) ) {
    print STDERR "Unable to open '$existsfile' for writing.\n";
    exit 1;
  }
  print EXISTS "$metafile\n";
  close EXISTS;

  print "Finished successfully.\n";
}

exit $ret;
